/*
 * File:        common.h
 * Purpose:     Common defines
 * Author:      Peter Ivanov
 * Modified by:
 * Created:     2007-05-19 11:29:32
 * Last modify: 2016-04-22 Pascal Chour
 * Copyright:   (C) Peter Ivanov, 2007
 * Copyright:   (C) Pascal Chour pour les modifications
 * Licence:     GPL
 */

/**
 * \file common.h
 * \brief Common defines
 * \author Peter Ivanov
 */
#ifndef __INCLUDE_COMMON_H
#define __INCLUDE_COMMON_H



#define BTN1                (BIT4)
#define BTN2                (BIT5)
#define BTN3                (BIT6)
#define BTN4                (BIT7)
#define BTN_MASK            (BTN1 | BTN2 | BTN3 | BTN4)
// Bouttons alias
#define BTN_MENU            (BTN1)
#define BTN_UP              (BTN3)
#define BTN_DOWN            (BTN2)
#define BTN_QUIT            (BTN4)
#define BTN_OK              (BTN4)

#define STATUS_LED          (BIT3)            //STATUS_LED - P1.3
#define DALLAS              (P2IN & BIT7)     //P2.7 - DALLAS

#ifndef bool_t
typedef char bool_t;
#endif // bool_t
#ifndef TRUE
#define TRUE                1
#endif // TRUE
#ifndef FALSE
#define FALSE               0
#endif // FALSE

/* Define pour programme Geiger - Pascal Chour */

/* ------- VERSION DU PROGRAMME ---------*/
/* 8 caractres          12345678        */
/* car utilisation de writesp            */

#define version_pgm    ("1.3") 

/*------ n de srie du compteur --------*/
#define serial_number  ("1")  

/*------- Modle du compteur ------------*/
#define counter_model ("PCGM5")


/* --------------------------------------*/



/* variables d'tat du systme */


#define periode (1)                        // periode en secondes 
#define periode_par_minute (60/periode)    // Nombre de periodes par minute.
#define nb_minutes_par_24h  (1440)         // nb de minutes en 24H
#define alarme_defaut (40)                 // valeur de seuil pour alarme

/* principaux tats du systme */

#define E_DIALOGUE (0x01)         // mode dialogue en cours
#define E_ALIM_EXTERNE (0x02)     // Alimentation externe branche
#define E_ALARME (0x04)           // Alamre en cours
#define E_REVEIL (0x10)           // le dormeur doit se rveiller... 
#define E_TEST_BAT (0x20)         // pour tester la batterie
#define E_EMET_COMPTAGE (0x40)    // pour mettre la valeur en CPM

/* codes d'erreur */

#define ERR_pas_erreur (0)        // pas d'erreur 


#define INACTIVITE_MAX (20)       // pour sortie du mode dialogue si inactivit (en secondes)
#define ALARME_MAX     (20)       // dure de l'alarme en secondes

#define BUF_MAX (40)              // taille max d'un buffer

struct trecept 
  {bool_t a_traiter;
  int  index;
  char buf[BUF_MAX];
  };
  

/* 
Timer en "mode normal". La mise  jour du comptage a lieu toutes les TIMER_NORMAL secondes.
Lorsqu'il y a une alarme ou que le compteur est aliment par USB, la mise
 jour se fait toutes les secondes (wtachdog).
De mme, les contrles accessoires (vrification batterie, bouton poussoir, etc. ne se font que 
toutes les TIMER_NORMAL secondes.
*/
#define TIMER_NORMAL   (10)  

#define FREQ_PROC_DIV_1000 (1000) // frquence du processeur divise par 1000

#endif // __INCLUDE_COMMON_H 
